@@ -33,6 +33,30 @@ class BaseModelFormMixin:
         self.validate_subject_identifier()
         return cleaned_data
 
+    @property
+    def subject_identifier(self) -> str:
+        """Returns subject identifier.
+
+        Assumes a non-CRF with model field subject_identifier.
+        """
+        if "subject_identifier" in self.cleaned_data:
+            subject_identifier = self.cleaned_data.get("subject_identifier")
+        else:
+            subject_identifier = self.instance.subject_identifier
+        if not subject_identifier:
+            raise ValidationError("Invalid. Subject identifier cannot be none.")
+        return subject_identifier
+
+    @property
+    def report_datetime(self) -> datetime | None:
+        """Returns the report_datetime in UTC from cleaned_data,
+        if key exists, else returns the instance report_datetime.
+        """
+        if self.report_datetime_field_attr in self.cleaned_data:
+            return to_utc(self.cleaned_data.get(self.report_datetime_field_attr))
+        else:
+            return getattr(self.instance, self.report_datetime_field_attr)
+
     def validate_subject_identifier(self) -> None:
         """Validates subject_identifier exists in RegisteredSubject"""
         try:
@@ -47,27 +71,3 @@ class BaseModelFormMixin:
                     )
                 }
             )
-
-    @property
-    def subject_identifier(self) -> str:
-        """Returns subject identifier.
-
-        Assumes a non-CRF with model field subject_identifier.
-        """
-        if (
-            subject_identifier := self.cleaned_data.get("subject_identifier")
-            or self.instance.subject_identifier
-        ):
-            return subject_identifier
-        else:
-            raise ValidationError("Invalid. Subject identifier cannot be none.")
-
-    @property
-    def report_datetime(self) -> datetime | None:
-        """Returns the report_datetime in UTC from cleaned_data,
-        if key exists, else returns the instance report_datetime.
-        """
-        if self.report_datetime_field_attr in self.cleaned_data:
-            return to_utc(self.cleaned_data.get(self.report_datetime_field_attr))
-        else:
-            return getattr(self.instance, self.report_datetime_field_attr)
